==> idrive-business-base-sdk-data-common-1.0.6-20250815.072810-3-sources.jar: com/digiwin/athena/atdm/UiBotConstants.java <==
package com.digiwin.athena.atdm;

public final class UiBotConstants {
    public static final String RECYCLE_DATA_KEY = "RECYCLE__DATA_KEY";

    /**
     * ESP服务类别
     */
    public static final String DATA_SOURCE_DATA_KEY="__DATA_KEY";
    /**
     * ESP服务类别
     */
    public static final String ACTION_CATEGORY_ESP="ESP";


    /**
     * 合并任务卡的key
     */
    public static final String ACTION_RETURN_PARAMS_KEY="ACTION_RETURN_PARAMS";
    /**
     *  目标退回数据
     */
    public static final String ACTION_TARGET_RETURN_DATA="individual_data_info";

    /**
     * ATMC
     */
    public static final String ACTION_CATEGORY_UIBOT="UIBOT";
    public static final String ACTION_CATEGORY_ABT="abt";

    public static final String  ACTION_CATEGORY_RAW_DATA = "RAWDATA";

    /**
     * BPM服务关键字
     */
    public static final String ACTION_CATEGORY_BPM="WF";
    /**
     * 任务引擎
     */
    public static final String ACTION_CATEGORY_TASK_ENGINE="TaskEngine";

    /**
     * 任务引擎
     */
    public static final String ACTION_CATEGORY_WORKFLOW="workflow";

    /**
     * 任务引擎之 PTM
     */
    public static final String ACTION_CATEGORY_PTM = "PTM";

    /**
     * 任务引擎之 PTM
     */
    public static final String ACTION_PTM_DATA = "PTM_DATA";

    /**
     * BPM服务关键字
     */
    public static final String ACTION_CATEGORY_SD="SD";

    /**
     * 手动发起项目
     */
    public static final String ACTION_CATEGORY_MANUAL_PROJECT = "MANUALPROJECT";

    /**
     * 新手动发起项目
     */
    public static final String ACTION_CATEGORY_MANUAL_PROJECT_NEW = "MANUALPROJECT_NEW";

    /**
     * EPS服务KEY的加密算法
     */
    public static final String ESP_KEY_ALGORITHM="MD5";
    /**
     * ESP服务KEY的加密字符串编码
     */
    public static final String ESP_KEY_CHARSET_UTF8="utf-8";

    /**
     * ThemeMap服务关键字
     */
    public static final String ACTION_CATEGORY_TM="TM";

    /**
     * ATMC变更任务数据源
     */
    public static final String ACTION_CATEGORY_ATMC_CHANGE="ATMC_CHANGE";

    /**
     * ATMC数据源
     */
    public static final String ACTION_CATEGORY_ATMC ="ATMC";

    /**
     * RECYCLE数据源
     */
    public static final String ACTION_CATEGORY_RECYCLE = "RECYCLE";

    /**
     * 已终止数据 数据源
     */
    public static final String ACTION_CATEGORY_TERMINATE_DATA = "TERMINATE_DATA";

    /**
     * 已撤回数据 数据源
     */
    public static final String ACTION_CATEGORY_WITHDRAW_DATA = "WITHDRAW_DATA";

    /**
     * “已搁置”数据源定义
     */
    public static final String ACTION_CATEGORY_SHELVED_DATA = "SHELVED_DATA";

    /**
     * RECYCLE数据源
     */
    public static final String ACTION_CATEGORY_MANUAL_TASK = "MANUAL_TASK";

    /**
     * 客户端来源标识
     */
    public static final String LINE_PLATFORM="line";

    /**
     * 客户端来源标识
     */
    public static final String MOBILE_PLATFORM="mobileplatform";

    /**
     * 标准前端
     */
    public static final String STANDARD_WEB = "standardweb";

    /**
     * DataSourceProcess执行的时机点，全部action执行完成后
     */
    public static final String DATA_PROCESS_ACTIVE_POINT_EXECUTE_COMPLETED = "executeCompleted";

    public static final String UIBOT_FIELDS_CHECKED ="uibot_checked";
    public static final String UIBOT_FIELDS_ID ="uibot_id";

    public static final String PAGE_CODE_BASIC_DATA = "basic-data";

    public static final String PATTERN_DIALOG = "DIALOG";

    /**
     * 任务合并时，start-new-process action 的准备好的参数在 extendParas 中 key 的名称
     */
    public static final String MERGED_SUBMIT_DATA = "mergedSubmitData";

    /**
     * 任务撤回的id
     */
    public static final String UIBOT_RETRIVE ="uibot_retrive";

    public static final String UIBOT_TASK_WITHDRAW ="uibot_task_withdraw";

    public static final String DATA_UNIFORMITY_SUBMIT = "DATA_UNIFORMITY_SUBMIT";

    public static final String DATA_AFC = "AFC";

    /**
     * 低代码平台数据中心
     */
    public static final String DATA_LCDP = "LCDP";

    public static final String SEMICOLON = ";";

    public interface FieldName {
        String UIBOT_DATETIME = "uibot__dateTime";
    }

    /**
     * ESP服务类别
     */
    public static final String ACTION_CATEGORY_ASA="ASA";


    /**
     * ATMC 处理打印
     */
    public static final String ACTION_CATEGORY_ATMC_PRINT = "ATMC_PRINT";

    /**
     * 导入保存按钮用
     */
    public static final String RE_IMPORT = "RE_IMPORT";
}

==> idrive-business-base-sdk-data-common-1.5.0-20250903.021022-12-sources.jar: com/digiwin/athena/atdm/UiBotConstants.java <==
package com.digiwin.athena.atdm;

public final class UiBotConstants {
    public static final String RECYCLE_DATA_KEY = "RECYCLE__DATA_KEY";

    /**
     * ESP服务类别
     */
    public static final String DATA_SOURCE_DATA_KEY="__DATA_KEY";
    /**
     * ESP服务类别
     */
    public static final String ACTION_CATEGORY_ESP="ESP";


    /**
     * 合并任务卡的key
     */
    public static final String ACTION_RETURN_PARAMS_KEY="ACTION_RETURN_PARAMS";
    /**
     *  目标退回数据
     */
    public static final String ACTION_TARGET_RETURN_DATA="individual_data_info";

    /**
     * ATMC
     */
    public static final String ACTION_CATEGORY_UIBOT="UIBOT";
    public static final String ACTION_CATEGORY_ABT="abt";

    public static final String  ACTION_CATEGORY_RAW_DATA = "RAWDATA";

    /**
     * BPM服务关键字
     */
    public static final String ACTION_CATEGORY_BPM="WF";
    /**
     * 任务引擎
     */
    public static final String ACTION_CATEGORY_TASK_ENGINE="TaskEngine";

    /**
     * 任务引擎
     */
    public static final String ACTION_CATEGORY_WORKFLOW="workflow";

    /**
     * 任务引擎之 PTM
     */
    public static final String ACTION_CATEGORY_PTM = "PTM";

    /**
     * 任务引擎之 PTM
     */
    public static final String ACTION_PTM_DATA = "PTM_DATA";

    /**
     * BPM服务关键字
     */
    public static final String ACTION_CATEGORY_SD="SD";

    /**
     * 手动发起项目
     */
    public static final String ACTION_CATEGORY_MANUAL_PROJECT = "MANUALPROJECT";

    /**
     * 新手动发起项目
     */
    public static final String ACTION_CATEGORY_MANUAL_PROJECT_NEW = "MANUALPROJECT_NEW";

    /**
     * EPS服务KEY的加密算法
     */
    public static final String ESP_KEY_ALGORITHM="MD5";
    /**
     * ESP服务KEY的加密字符串编码
     */
    public static final String ESP_KEY_CHARSET_UTF8="utf-8";

    /**
     * ThemeMap服务关键字
     */
    public static final String ACTION_CATEGORY_TM="TM";

    /**
     * ATMC变更任务数据源
     */
    public static final String ACTION_CATEGORY_ATMC_CHANGE="ATMC_CHANGE";

    /**
     * ATMC数据源
     */
    public static final String ACTION_CATEGORY_ATMC ="ATMC";

    /**
     * RECYCLE数据源
     */
    public static final String ACTION_CATEGORY_RECYCLE = "RECYCLE";

    /**
     * 已终止数据 数据源
     */
    public static final String ACTION_CATEGORY_TERMINATE_DATA = "TERMINATE_DATA";

    /**
     * 已撤回数据 数据源
     */
    public static final String ACTION_CATEGORY_WITHDRAW_DATA = "WITHDRAW_DATA";

    /**
     * “已搁置”数据源定义
     */
    public static final String ACTION_CATEGORY_SHELVED_DATA = "SHELVED_DATA";

    /**
     * RECYCLE数据源
     */
    public static final String ACTION_CATEGORY_MANUAL_TASK = "MANUAL_TASK";

    /**
     * 客户端来源标识
     */
    public static final String LINE_PLATFORM="line";

    /**
     * 客户端来源标识
     */
    public static final String MOBILE_PLATFORM="mobileplatform";

    /**
     * 标准前端
     */
    public static final String STANDARD_WEB = "standardweb";

    /**
     * DataSourceProcess执行的时机点，全部action执行完成后
     */
    public static final String DATA_PROCESS_ACTIVE_POINT_EXECUTE_COMPLETED = "executeCompleted";

    public static final String UIBOT_FIELDS_CHECKED ="uibot_checked";
    public static final String UIBOT_FIELDS_ID ="uibot_id";

    public static final String PAGE_CODE_BASIC_DATA = "basic-data";

    public static final String PATTERN_DIALOG = "DIALOG";

    public static final String PATTERN_CALENDAR = "CALENDAR";

    public static final String PLATFORM_CALENDAR_CODE = "uibotManualTask";

    /**
     * 任务合并时，start-new-process action 的准备好的参数在 extendParas 中 key 的名称
     */
    public static final String MERGED_SUBMIT_DATA = "mergedSubmitData";

    /**
     * 任务撤回的id
     */
    public static final String UIBOT_RETRIVE ="uibot_retrive";

    public static final String UIBOT_TASK_WITHDRAW ="uibot_task_withdraw";

    public static final String DATA_UNIFORMITY_SUBMIT = "DATA_UNIFORMITY_SUBMIT";

    public static final String DATA_AFC = "AFC";

    /**
     * 低代码平台数据中心
     */
    public static final String DATA_LCDP = "LCDP";

    public static final String SEMICOLON = ";";

    public interface FieldName {
        String UIBOT_DATETIME = "uibot__dateTime";
    }

    /**
     * ESP服务类别
     */
    public static final String ACTION_CATEGORY_ASA="ASA";


    /**
     * 导入保存按钮用
     */
    public static final String RE_IMPORT = "RE_IMPORT";
}
